@@ -265,17 +265,23 @@ class TestServicePrincipalAuth(unittest.TestCase):
 
     def test_build_credential(self):
         # secret
-        cred = ServicePrincipalAuth.build_credential("test_secret")
+        cred = ServicePrincipalAuth.build_credential(secret_or_certificate="test_secret")
         assert cred == {"client_secret": "test_secret"}
 
         # secret with '~', which is preserved as-is
-        cred = ServicePrincipalAuth.build_credential("~test_secret")
+        cred = ServicePrincipalAuth.build_credential(secret_or_certificate="~test_secret")
         assert cred == {"client_secret": "~test_secret"}
 
+        # certificate as password (deprecated)
+        current_dir = os.path.dirname(os.path.realpath(__file__))
+        test_cert_file = os.path.join(current_dir, 'sp_cert.pem')
+        cred = ServicePrincipalAuth.build_credential(secret_or_certificate=test_cert_file)
+        assert cred == {'certificate': test_cert_file}
+
         # certificate
         current_dir = os.path.dirname(os.path.realpath(__file__))
         test_cert_file = os.path.join(current_dir, 'sp_cert.pem')
-        cred = ServicePrincipalAuth.build_credential(test_cert_file)
+        cred = ServicePrincipalAuth.build_credential(certificate=test_cert_file)
         assert cred == {'certificate': test_cert_file}
 
         # certificate path with '~', which expands to HOME folder
@@ -283,11 +289,12 @@ class TestServicePrincipalAuth(unittest.TestCase):
         home = os.path.expanduser('~')
         home_cert = os.path.join(home, 'sp_cert.pem')  # C:\Users\username\sp_cert.pem
         shutil.copyfile(test_cert_file, home_cert)
-        cred = ServicePrincipalAuth.build_credential(os.path.join('~', 'sp_cert.pem'))  # ~\sp_cert.pem
+        cred = ServicePrincipalAuth.build_credential(certificate=os.path.join('~', 'sp_cert.pem'))  # ~\sp_cert.pem
         assert cred == {'certificate': home_cert}
         os.remove(home_cert)
 
-        cred = ServicePrincipalAuth.build_credential(test_cert_file, use_cert_sn_issuer=True)
+        # Certificate with use_cert_sn_issuer=True
+        cred = ServicePrincipalAuth.build_credential(certificate=test_cert_file, use_cert_sn_issuer=True)
         assert cred == {'certificate': test_cert_file, 'use_cert_sn_issuer': True}
 
         # client assertion
