@@ -85,10 +85,7 @@ def patch_long_run_operation_delay(unit_test):
         return
 
     mock_in_unit_test(unit_test,
-                      'msrestazure.azure_operation.AzureOperationPoller._delay',
-                      _shortcut_long_run_operation)
-    mock_in_unit_test(unit_test,
-                      'msrestazure.polling.arm_polling.ARMPolling._delay',
+                      'azure.mgmt.core.polling.arm_polling.ARMPolling._delay',
                       _shortcut_long_run_operation)
     mock_in_unit_test(unit_test,
                       'azure.cli.core.commands.LongRunningOperation._delay',
