@@ -3,11 +3,12 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from azure.cli.testsdk import ScenarioTest, StorageAccountPreparer, ResourceGroupPreparer, record_only
+from azure.cli.testsdk import ScenarioTest, StorageAccountPreparer, ResourceGroupPreparer, record_only, live_only
 
 
 class AcrAgentPoolCommandsTests(ScenarioTest):
 
+    @live_only()
     @ResourceGroupPreparer()
     def test_acr_agentpool(self, resource_group):
         # Agentpool prerequisites for agentpool testing
