@@ -9,7 +9,6 @@ import argparse
 from knack.util import CLIError
 from azure.cli.core.azclierror import UnrecognizedArgumentError
 from ._validators import read_base_64_file
-from ._util import enum_check
 
 
 # pylint: disable=protected-access
@@ -135,41 +134,6 @@ class SslProfilesCreate(argparse._AppendAction):
         return d
 
 
-class NatRuleCreate(argparse._AppendAction):
-    def __call__(self, parser, namespace, values, option_string=None):
-        action = self.get_action(values, option_string)
-        super(NatRuleCreate, self).__call__(parser, namespace, action, option_string)
-
-    def get_action(self, values, option_string):  # pylint: disable=no-self-use
-        try:
-            properties = defaultdict(list)
-            for (k, v) in (x.split('=', 1) for x in values):
-                properties[k].append(v)
-            properties = dict(properties)
-        except ValueError:
-            raise UnrecognizedArgumentError('usage error: {} [KEY=VALUE ...]'.format(option_string))
-        d = {}
-        for k in properties:
-            kl = k.lower()
-            v = properties[k]
-            if kl == 'type':
-                d['type'] = enum_check(v[0], ['Static', 'Dynamic'])
-            elif kl == 'name':
-                d['name'] = v[0]
-            elif kl == 'mode':
-                d['mode'] = enum_check(v[0], ['EgressSnat', 'IngressSnat'])
-            elif kl == 'internal-mappings':
-                d['internal_mappings'] = _split(v[0])
-            elif kl == 'external-mappings':
-                d['external_mappings'] = _split(v[0])
-            elif kl == 'ip-config-id':
-                d['ip_config_id'] = v[0]
-            else:
-                raise UnrecognizedArgumentError('key error: key must be one of type, mode, internal-mappings,'
-                                                'external-mappings, ip-config-id')
-        return d
-
-
 class AddMappingRequest(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
         action = self.get_action(values, option_string)
@@ -219,6 +183,8 @@ class WAFRulesCreate(argparse._AppendAction):
                 d['action'] = v[0]
             elif kl == 'state':
                 d['state'] = v[0]
+            elif kl == 'sensitivity':
+                d['sensitivity'] = v[0]
             else:
                 raise UnrecognizedArgumentError('key error: key must be one of rule-id, action and state.')
         return d
