@@ -504,3 +504,53 @@ class KubernetesConnectionScenarioTest(ScenarioTest):
 
         # delete connection
         self.cmd('aks connection delete --id {} --yes'.format(connection_id))
+
+    @record_only()
+    def test_kubernetes_appconfig_e2e(self):
+        self.kwargs.update({
+            'subscription': get_subscription_id(self.cli_ctx),
+            'source_resource_group': 'servicelinker-test-linux-group',
+            'target_resource_group': 'servicelinker-test-linux-group',
+            'cluster': 'servicelinker-storage-cluster',
+            'config_store': 'servicelinker-app-configuration'
+        })
+
+        # prepare params
+        name = 'testconn'
+        source_id = SOURCE_RESOURCES.get(RESOURCE.KubernetesCluster).format(**self.kwargs)
+        target_id = TARGET_RESOURCES.get(RESOURCE.AppConfig).format(**self.kwargs)
+
+        # create connection
+        self.cmd('aks connection create appconfig --connection {} --source-id {} --target-id {} '
+                 '--secret --client-type python --use-appconfig-extension'.format(name, source_id, target_id))
+
+        # list connection
+        connections = self.cmd(
+            'aks connection list --source-id {}'.format(source_id),
+            checks=[
+                self.check('length(@)', 1),
+                self.check('[0].authInfo.authType', 'secret'),
+                self.check('[0].clientType', 'python'),
+                self.check('[0].targetService.resourceProperties.connectWithKubernetesExtension', True)
+            ]
+        ).get_output_in_json()
+        connection_id = connections[0].get('id')
+
+        # update connection
+        self.cmd('aks connection update appconfig --id {} --client-type dotnet'.format(connection_id),
+                 checks=[
+                     self.check('clientType', 'dotnet'),
+                     self.check('authInfo.authType', 'secret')
+        ])
+
+        # list configuration
+        self.cmd('aks connection list-configuration --id {}'.format(connection_id))
+
+        # validate connection
+        self.cmd('aks connection validate --id {}'.format(connection_id))
+
+        # show connection
+        self.cmd('aks connection show --id {}'.format(connection_id))
+
+        # delete connection
+        self.cmd('aks connection delete --id {} --yes'.format(connection_id))
